using System;

namespace WpfCoreExceptionDialog.Dialogs
{
    public class AssemblyPoint : IComparable
    {
        /// <summary>
        /// Der Name der Assembly ohne Vereichnis.
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Der voll qualifizierte Name der Assembly.
        /// </summary>
        public string FullName { get; set; }

        /// <summary>
        /// Der Pfad oder UNC-Pfad der Assembly.
        /// </summary>
        public string Location { get; set; }

        /// <summary>
        /// Der ursprnglich angegebene Speicherort der Assembly.
        /// </summary>
        public string Codebase { get; set; }

        /// <summary>
        /// Eine Zeichenfolge, die die
        /// Version der CLR darstellt, die in der Assembly gespeichert wurde.
        /// </summary>
        public string Imageversion { get; set; }

        /// <summary>
        /// Ein Wert, der angibt, ob die Assembly aus dem
        /// globalen Assemblycache geladen wurde.
        /// </summary>
        public bool LoadFromcache { get; set; }

        /// <summary>
        /// Die Dateieigenschaften der Assembly.
        /// </summary>
        public AttributesPoint Attributes { get; set; }

        /// <summary>
        /// Vergleicht diese Instanz mit einem angegebenen Objekt,
        /// und gibt eine Angabe ber das Verhltnis der entsprechenden Werte zurck.
        /// </summary>
        /// <param name="obj">Ein Objekt, das mit dieser Instanz verglichen werden soll.</param>
        /// <returns>Eine Ganzzahl mit Vorzeichen, die die relative Reihenfolge dieser Instanz und obj angibt.</returns>
        public int CompareTo(object obj)
        {
            if (obj is AssemblyPoint)
            {
                AssemblyPoint temp = (AssemblyPoint)obj;

                return Name.CompareTo(temp.Name);
            }

            throw new ArgumentException("Das Objekt " + obj.ToString() + " ist nicht vom Typ " + typeof(AssemblyPoint).Name + " und kann nicht sortiert werden.");
        }
    }
}