using System;
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Windows.Input;

namespace WpfCoreExceptionDialog.Dialogs
{
    public class RelayCommand : ICommand
    {
        private readonly WeakAction _execute;
        private readonly WeakFunc<bool> _canExecute;

        [method: CompilerGenerated]
        [CompilerGenerated]
        public event EventHandler CanExecuteChanged;

        public RelayCommand(Action execute, bool keepTargetAlive = false) : this(execute, null, keepTargetAlive)
        {
        }

        public RelayCommand(Action execute, Func<bool> canExecute, bool keepTargetAlive = false)
        {
            if (execute == null)
            {
                throw new ArgumentNullException("execute");
            }
            this._execute = new WeakAction(execute, keepTargetAlive);
            if (canExecute != null)
            {
                this._canExecute = new WeakFunc<bool>(canExecute, keepTargetAlive);
            }
        }

        public void RaiseCanExecuteChanged()
        {
            EventHandler handler = this.CanExecuteChanged;
            if (handler != null)
            {
                handler(this, EventArgs.Empty);
            }
        }

        public bool CanExecute(object parameter = null)
        {
            return this._canExecute == null || ((this._canExecute.IsStatic || this._canExecute.IsAlive) && this._canExecute.Execute());
        }

        public virtual void Execute(object parameter = null)
        {
            if (this.CanExecute(parameter) && this._execute != null && (this._execute.IsStatic || this._execute.IsAlive))
            {
                this._execute.Execute();
            }
        }
    }

    public class RelayCommand<T> : ICommand
    {
        private readonly WeakAction<T> _execute;
        private readonly WeakFunc<T, bool> _canExecute;

        [method: CompilerGenerated]
        [CompilerGenerated]
        public event EventHandler CanExecuteChanged;

        public RelayCommand(Action<T> execute, bool keepTargetAlive = false) : this(execute, null, keepTargetAlive)
        {
        }

        public RelayCommand(Action<T> execute, Func<T, bool> canExecute, bool keepTargetAlive = false)
        {
            if (execute == null)
            {
                throw new ArgumentNullException("execute");
            }
            this._execute = new WeakAction<T>(execute, keepTargetAlive);
            if (canExecute != null)
            {
                this._canExecute = new WeakFunc<T, bool>(canExecute, keepTargetAlive);
            }
        }

        public void RaiseCanExecuteChanged()
        {
            EventHandler handler = this.CanExecuteChanged;
            if (handler != null)
            {
                handler(this, EventArgs.Empty);
            }
        }

        public bool CanExecute(object parameter)
        {
            if (this._canExecute == null)
            {
                return true;
            }
            if (this._canExecute.IsStatic || this._canExecute.IsAlive)
            {
                if (parameter == null && typeof(T).GetTypeInfo().IsValueType)
                {
                    return this._canExecute.Execute(default(T));
                }
                if (parameter == null || parameter is T)
                {
                    return this._canExecute.Execute((T)((object)parameter));
                }
            }
            return false;
        }

        public virtual void Execute(object parameter)
        {
            if (this.CanExecute(parameter) && this._execute != null && (this._execute.IsStatic || this._execute.IsAlive))
            {
                if (parameter == null)
                {
                    if (typeof(T).GetTypeInfo().IsValueType)
                    {
                        this._execute.Execute(default(T));
                        return;
                    }
                    this._execute.Execute((T)((object)parameter));
                    return;
                }
                else
                {
                    this._execute.Execute((T)((object)parameter));
                }
            }
        }
    }
}